@@ -196,6 +196,15 @@ def parse_footnote(document, container, elem):
     container.elements.append(foot)
 
 
+def parse_endnote(document, container, elem):
+    "Parse the endnote element."
+
+    _rid =  elem.attrib[_name('{{{w}}}id')]
+
+    note = doc.Endnote(_rid)
+    container.elements.append(note)
+
+
 def parse_alternate(document, container, elem):
     txtbx = elem.find('.//'+_name('{{{w}}}txbxContent'))
     paragraphs = []
@@ -256,6 +265,11 @@ def parse_text(document, container, element):
     if foot is not None:
         parse_footnote(document, container, foot)
 
+    end = element.find(_name('{{{w}}}endnoteReference'))
+
+    if end is not None:
+        parse_endnote(document, container, end)
+
     sym = element.find(_name('{{{w}}}sym'))
 
     if sym is not None:
@@ -507,19 +521,35 @@ def parse_footnotes(document, xmlcontent):
     Footnotes are defined in file 'footnotes.xml'
     """
 
-    styles = etree.fromstring(xmlcontent)
+    footnotes = etree.fromstring(xmlcontent)
     document.footnotes = {}
 
-    for style in styles.xpath('.//w:footnote', namespaces=NAMESPACES):
-        _type = style.attrib.get(_name('{{{w}}}type'), None)
+    for footnote in footnotes.xpath('.//w:footnote', namespaces=NAMESPACES):
+        _type = footnote.attrib.get(_name('{{{w}}}type'), None)
 
         # don't know what to do with these now
         if _type in ['separator', 'continuationSeparator', 'continuationNotice']:
             continue
 
-        p = parse_paragraph(document, style.find(_name('{{{w}}}p')))
+#        p = parse_paragraph(document, footnote.find(_name('{{{w}}}p')))
+        paragraphs = [parse_paragraph(document, para) for para in footnote.xpath('.//w:p', namespaces=NAMESPACES)]
 
-        document.footnotes[style.attrib[_name('{{{w}}}id')]] = p
+        document.footnotes[footnote.attrib[_name('{{{w}}}id')]] = paragraphs
+
+
+def parse_endnotes(document, xmlcontent):
+    """Parse endnotes document.
+
+    Endnotes are defined in file 'endnotes.xml'
+    """
+
+    endnotes = etree.fromstring(xmlcontent)
+    document.endnotes = {}
+
+    for note in endnotes.xpath('.//w:endnote', namespaces=NAMESPACES):
+        paragraphs = [parse_paragraph(document, para) for para in note.xpath('.//w:p', namespaces=NAMESPACES)]
+
+        document.endnotes[note.attrib[_name('{{{w}}}id')]] = paragraphs
 
 
 def parse_numbering(document, xmlcontent):
@@ -590,6 +620,12 @@ def parse_from_file(file_object):
     except KeyError:
         logger.warning('Could not read footnotes.')
 
+    try:    
+        endnotes_content = file_object.read_file('endnotes.xml')
+        parse_endnotes(document, endnotes_content)    
+    except KeyError:
+        logger.warning('Could not read endnotes.')
+
     try:
         numbering_content = file_object.read_file('numbering.xml')
         parse_numbering(document, numbering_content)    
